import { defineStore } from 'pinia';
import { ref, computed } from 'vue';

export const useApiStore = defineStore('api', () => {
  // State
  const config = ref({
    apiUri: localStorage.getItem('pvc_api_uri') || '',
    apiKey: localStorage.getItem('pvc_api_key') || '',
    updateInterval: parseInt(localStorage.getItem('pvc_update_interval')) || 15 // Default to 15s
  });

  // Computed
  const isConfigured = computed(() => {
    return Boolean(config.value.apiUri && config.value.apiKey);
  });

  // Actions
  const updateConfig = (newConfig) => {
    // Ensure interval is between 5 and 300 seconds
    const interval = Math.min(300, Math.max(5, parseInt(newConfig.updateInterval) || 15));
    
    config.value = {
      ...newConfig,
      updateInterval: interval
    };
    
    // Save to localStorage
    localStorage.setItem('pvc_api_uri', newConfig.apiUri);
    localStorage.setItem('pvc_api_key', newConfig.apiKey);
    localStorage.setItem('pvc_update_interval', interval.toString());
  };

  const fetchStatus = async () => {
    try {
      const response = await fetch('/api/status', {
        headers: {
          'X-API-URI': config.value.apiUri,
          'X-API-Key': config.value.apiKey
        }
      });

      if (!response.ok) {
        throw new Error(`HTTP error! status: ${response.status}`);
      }

      return await response.json();
    } catch (error) {
      console.error('Error fetching cluster status:', error);
      throw error;
    }
  };

  const fetchNodes = async () => {
    try {
      const response = await fetch('/api/node', {
        headers: {
          'X-API-URI': config.value.apiUri,
          'X-API-Key': config.value.apiKey
        }
      });

      if (!response.ok) {
        throw new Error(`HTTP error! status: ${response.status}`);
      }

      const data = await response.json();
      return Object.entries(data).map(([name, details]) => ({
        name,
        ...details,
        vms: Array.isArray(details.vms) ? details.vms : 
             Object.keys(details.vms || {})
      }));
    } catch (error) {
      console.error('Error fetching node data:', error);
      throw error;
    }
  };

  const fetchVMs = async () => {
    try {
      const response = await fetch('/api/vm', {
        headers: {
          'X-API-URI': config.value.apiUri,
          'X-API-Key': config.value.apiKey
        }
      });

      if (!response.ok) {
        throw new Error(`HTTP error! status: ${response.status}`);
      }

      const data = await response.json();
      return Object.entries(data).map(([name, details]) => ({
        name,
        ...details
      }));
    } catch (error) {
      console.error('Error fetching VM data:', error);
      throw error;
    }
  };

  return {
    config,
    isConfigured,
    updateConfig,
    fetchStatus,
    fetchNodes,
    fetchVMs
  };
});
